@@ -1,4 +1,7 @@
-from neuro_helper.entity import Space
+from neuro_helper.abstract.map import Space
+
+
+__all__ = ["task_order"]
 
 
 def task_order(space: Space, with_rest=True):
