@@ -95,13 +95,14 @@ def calc_a_lzc(ts, norm_factor=None):
     """
     Calculates lempel-ziv complexity of a single time series.
     :param ts: a time-series: nx1
-    :param norm_factor: the normalization factor. If none, the default value will be calculated: n / ln(n)
+    :param norm_factor: the normalization factor. If none, the output will not be normalized
     :return: the lempel-ziv complexity
     """
-    if not norm_factor:
-        norm_factor = calc_lzc_norm_factor(ts)
     bin_ts = np.char.mod('%i', ts >= np.median(ts))
-    return lempel_ziv_complexity("".join(bin_ts)) / norm_factor
+    value = lempel_ziv_complexity("".join(bin_ts))
+    if norm_factor:
+        value /= norm_factor
+    return value
 
 
 def calc_lzc(data, norm_factor=None, n_job=None, threading=False):
@@ -133,29 +134,26 @@ def calc_ple(psd, freq, is_log=False, n_job=None, threading=False):
 
 def calc_peak(data, fs, low, high, apply_median_filter, n_job=None):
     data, freq_l, freq_h = fir_filter(data, fs, max_freq_low=low, min_freq_high=high, pass_type="bp")
-    n_wave, n_sample = data.shape
-    hilb_data = hilbert(data, n_sample, axis=0)
+    hilb_data = hilbert(data)
     phase = np.angle(hilb_data)
     instant_freq = fs * np.diff(np.unwrap(phase)) / (2 * np.pi)
 
     if not apply_median_filter:
         return instant_freq
 
+    n_wave, n_sample = instant_freq.shape
     # apply median filter to attenuate large "blips" in instantaneous frequency
     n_window = 10
     win_lengths = np.round(np.linspace(10, 400, n_window) * fs / (2 * 1000)).astype(int)
 
     def win_calc(wl_, si_):
-        start, stop = max(si_ - wl_, 0), min(si_ + wl_, n_sample)
+        start, stop = max(si_ - wl_, 0), min(si_ + wl_, n_sample - 1)
         return np.median(np.sort(instant_freq[:, start: stop], axis=1), axis=1)
 
     n_job = n_job if n_job else 10
     phased_med = np.zeros((n_window, n_sample, n_wave))
     for wi, wl in enumerate(win_lengths):
         phased_med[wi, :, :] = np.asarray(Parallel(n_jobs=n_job)(delayed(win_calc)(wl, si) for si in range(n_sample)))
-        # for si in range(n_sample):
-        #     start, stop = max(si - win_lengths[wi], 0), min(si + win_lengths[wi], n_sample)
-        #     phased_med[wi, si, :] = np.median(np.sort(instant_freq[:, start: stop], axis=1), axis=1)
 
     sliding_instant_freq = np.mean(phased_med, axis=0).T
     return sliding_instant_freq
